const xmlbuilder = require('xmlbuilder')
const jsonToTable = require('./jsonToTable')

class HTMLBuilder {
  constructor ({ tableAttrs }) {
    this.tableAttrs = tableAttrs || {}
  }

  table(next) {
    this.xmlbuilder = xmlbuilder.create('table', null, null, { headless: true, allowEmpty: true })
    this.xmlbuilder.att(this.tableAttrs)
    next()
  }

  head(next) {
    this.xmlbuilder = this.xmlbuilder.ele('thead')
    next()
    this.xmlbuilder = this.xmlbuilder.up()
  }

  body(next) {
    this.xmlbuilder = this.xmlbuilder.ele('tbody')
    next()
    this.xmlbuilder = this.xmlbuilder.up()
  }

  row(next) {
    this.xmlbuilder = this.xmlbuilder.ele('tr')
    next()
    this.xmlbuilder = this.xmlbuilder.up()
  }

  cell(data, at) {
    const tagName = at.isHead ? 'th' : 'td'
    const attrs = {}
    if (at.rowSpan > 1) {
      attrs.rowSpan = at.rowSpan
    }
    if (at.colSpan > 1) {
      attrs.colSpan = at.colSpan
    }
    this.xmlbuilder = this.xmlbuilder.ele(tagName, attrs, data).up()
  }
}

function jsonToHTML (meta, data, tableAttrs = {}) {
  if (arguments.length === 1) {
    return jsonToHTML(null, arguments[0])
  }

  const builder = new HTMLBuilder({ tableAttrs })
  jsonToTable(meta, data, builder)
  return builder.xmlbuilder.end({ pretty: true, allowEmpty: true })
}

module.exports = jsonToHTML
